%define pkgname		embree
%define api_version	3
%define libmajor	3
%define libname_orig	%mklibname %{pkgname} %{api_version}
%define libname		%mklibname %{pkgname} %{api_version} %{libmajor}
%define develname	%mklibname -d %{pkgname} %{api_version}
%define staticdevname	%mklibname -d -s %{pkgname} %{api_version}

# limit the maximum number of parallel building processes to avoid
# running out of memory during building
%global		_smp_ncpus_max 2

Name:		%{pkgname}%{api_version}
Version:	3.13.5
Release:	%mkrel 2
Summary:	A collection of high-performance ray tracing kernels
Group:		Graphics/3D
License:	ASL 2.0
URL:		https://embree.github.io
Source:		https://github.com/%{pkgname}/%{pkgname}/archive/v%{version}/%{pkgname}-%{version}.tar.gz
Patch0:		embree-3.13.5-dont-force-std.patch
Patch1:		embree-fix-aarch64.patch

BuildRequires:	cmake
BuildRequires:	gcc-c++
%ifarch x86_64
# (akien) Current ISPC version doesn't support aarch64, and it's an optional dependency.
# Don't enable it for aarch64 without confirming that the above comment is solved!
BuildRequires:	ispc
%endif
BuildRequires:	pkgconfig(freeglut)
BuildRequires:	pkgconfig(glfw3)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(tbb)
BuildRequires:	pkgconfig(xmu)

# Use 64bit architectures because of SSE2 and up
ExclusiveArch:	x86_64 aarch64

%description
A collection of high-performance ray tracing kernels intended to
graphics application engineers that want to improve the performance of
their photo-realistic rendering applications.

%package -n %{libname}
Summary:	A collection of high-performance ray tracing kernels
Group:		System/Libraries
Provides:	%{libname_orig} = %{version}-%{release}
Provides:	%{pkgname}%{api_version} = %{version}-%{release}

%description -n %{libname}
A collection of high-performance ray tracing kernels intended to
graphics application engineers that want to improve the performance of
their photo-realistic rendering applications.

This package contains the library needed to run programs dynamically
linked with embree.

%package -n %{develname}
Summary:	Headers and development files of the embree library
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{pkgname}%{api_version}-devel = %{version}-%{release}
Provides:	%{libname_orig}-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	%{pkgname}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for the embree library. Install this package if you
want to compile applications using the embree library.

%prep
%autosetup -p1 -n %{pkgname}-%{version}

%build
%cmake \
	-DEMBREE_IGNORE_CMAKE_CXX_FLAGS:BOOL=OFF \
	-DCMAKE_CXX_FLAGS:STRING="%{optflags}" \
	-DCMAKE_C_FLAGS:STRING="%{optflags}" \
%ifnarch x86_64
	-DEMBREE_ISPC_SUPPORT:BOOL=OFF \
%endif
	-DEMBREE_RAY_MASK:BOOL=ON \
	-DEMBREE_BACKFACE_CULLING:BOOL=OFF \
	-DEMBREE_FILTER_FUNCTION:BOOL=ON \
	-DEMBREE_TUTORIALS:BOOL=OFF

%cmake_build

%install
%cmake_install

# Remove installed doc files
rm -rf %{buildroot}%{_docdir}/%{name}

%files -n %{libname}
%{_libdir}/*.so.%{libmajor}{,.*}

%files -n %{develname}
%license LICENSE.txt
%doc README.md CHANGELOG.md readme.pdf
%{_libdir}/lib*.so
%{_includedir}/*
%{_libdir}/cmake/%{pkgname}-%{version}/
%{_mandir}/man3/*


%changelog
* Sun Jan 28 2024 daviddavid <daviddavid> 3.13.5-2.mga10
+ Revision: 2035681
- rebuild for tbb 2021.11.0

* Fri Mar 03 2023 akien <akien> 3.13.5-1.mga9
+ Revision: 1946658
- Add upstream patch to fix aarch64 build
- Version 3.13.5

* Sun Oct 02 2022 ghibo <ghibo> 3.13.3-8.mga9
+ Revision: 1894101
- Revert to release 3.13.3, as 3.13.4 or 3.13.5 no longer builds on aarch64
- Revert to release 3.13.4.
- Remove Patch1.
- Reword Patch0.
- Avoid forcing EMBREE_ARM on aarch64
- Revert upstream patch to fix aarch64 building
- Force ARM target on aarch64 (issue https://github.com/embree/embree/issues/391)
- Disable forcing EMBREE_TARGET_SSE2=OFF as it has no effects.
- Force disabling SSE2 on non-x86_64 arch
- Update to release 3.13.5.
- Rework Patch0.

* Tue Aug 02 2022 akien <akien> 3.13.3-7.mga9
+ Revision: 1874324
- Re-enable embree3 build on aarch64, without ISPC which doesn't support it

* Thu Mar 31 2022 umeabot <umeabot> 3.13.3-6.mga9
+ Revision: 1835717
- Mageia 9 Mass Rebuild

* Wed Mar 30 2022 ghibo <ghibo> 3.13.3-5.mga9
+ Revision: 1834773
- Don't force -std= hardcoded.

* Wed Mar 30 2022 ghibo <ghibo> 3.13.3-4.mga9
+ Revision: 1833746
- Re-enable -std=c++20 (default for g++-12)
- Temporarily exclude aarch64
- Force C++14 for g++-12.
- Try ispc for aarch64.
- Drop support for mga7
- Update to release 3.13.3

* Tue Dec 28 2021 ghibo <ghibo> 3.13.2-1.mga9
+ Revision: 1765108
- Update to release 3.13.2

* Sun May 23 2021 akien <akien> 3.13.0-2.mga9
+ Revision: 1726175
- Version 3.13.0
- Adds support for aarch64, albeit without ispc for now

* Sat Oct 17 2020 ghibo <ghibo> 3.12.1-1.mga8
+ Revision: 1636570
- Update to release 3.12.1

* Thu Oct 08 2020 ghibo <ghibo> 3.12.0-1.mga8
+ Revision: 1632889
- Update to release 3.12.0

* Sun Sep 13 2020 ghibo <ghibo> 3.11.0-2.mga8
+ Revision: 1625468
- Rebuild against ispc-1.14.1
- Update to release 3.11.0

* Sun May 31 2020 ghibo <ghibo> 3.10.0-1.mga8
+ Revision: 1589217
- Update to release 3.10
- Upgrade to release 3.9.0

* Sat Feb 15 2020 umeabot <umeabot> 3.5.2-3.mga8
+ Revision: 1526505
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Mon May 27 2019 ghibo <ghibo> 3.5.2-2.mga7
+ Revision: 1399254
- Enable EMBREE_RAY_MASK (needed for blender2.8).
- Try to increase number of parallel building processes to 2.

* Sun May 26 2019 ghibo <ghibo> 3.5.2-1.mga7
+ Revision: 1399223
- imported package embree3


* Sat May 25 2019 ghibo <ghibo> 3.5.2-1.mga7
- Initial release based on FC package.
- Mageia libification.
